| PFSOSInteg | R Documentation |
survPFSOS()Helper Function for survPFSOS()
PFSOSInteg(u, t, transition)
u |
( |
t |
( |
transition |
( |
Numeric result of the integrand used to calculate the PFS*OS survival function.
Not all vectors u and t work here due to assertions in log_p11().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.